@@ -1,7 +1,7 @@
 # 2022.3.5
 from app.dmdsk import *
 
-def run():
+def run(rid=2575450):
 	
 	st.title("eid-version")
 	eidv = st.text_input("input a eidv", "152816246-2")
