@@ -202,6 +202,7 @@ config = {
 			"kw": { "type": "keyword", "index": "false" ,"store": "false", "ignore_above": 60},
 			"meta": { "type": "keyword", "index": "false" ,"store": "false"},
 			"dim": { "type": "keyword", "index": "false" },
+			"dims": { "type": "keyword", "index": "false" },
 			"tc": {"type": "integer" , "index": "false"},
 			"sc": {"type": "integer" , "index": "false"},
 			"isum": {"type": "integer" , "index": "false"},
@@ -223,7 +224,7 @@ config = {
 			"v": { "type": "keyword",  "index": "false"},
 			"n": { "type": "keyword",  "index": "false"},
 			"adj": { "type": "keyword",  "index": "false"},
-			"snt": { "type": "text", "analyzer": "standard","fielddata":"true"}
+			"snt": { "type": "text", "analyzer": "standard","store":"true"}
 		  }
 		}
 	}
