@@ -67,5 +67,6 @@ def hset_if_greater(r, key, eid, ver ):
 		print("ex:", e, eid)
 
 if __name__ == '__main__': 
-	logger = getlog()
-	print (logger) 
\ No newline at end of file
+	pass 
+	#logger = getlog()
+	#print (logger) 
\ No newline at end of file
