@@ -1,14 +1,15 @@
 # 2022.3.3  for yulk.sentbase.com  | uvicorn yulk:app --host 0.0.0.0 --port 18001 --reload
 import json,requests,hashlib,os
 from uvirun import * 
-from en import nlp, snts
+#from en import nlp, snts
+import en
 
 from collections import	defaultdict, Counter
 from dic.bnc_wordlist import * 
 @app.get('/yulk/keyness')  #def bnc_keyness(si:dict, si_sum:int=None):
 def text_keyness(text="I think that I am going to go to the cinema. The quick fox jumped over the lazy dog.", topk:int=20):  
 	''' 单词超用显著性 ''' 
-	doc = nlp(text) 
+	doc = spacy.nlp(text) 
 	si = Counter()
 	[ si.update({t.lemma_:1}) for t in doc if not t.pos_ in ('PROPN','PUNCT') and not t.is_stop]
 	res = bnc_keyness(dict(si), len(doc))
@@ -16,7 +17,7 @@ def text_keyness(text="I think that I am going to go to the cinema. The quick fo
 	return res[0:topk]
 
 from dic.word_idf import word_idf
-wordidf = lambda txt:  (si := Counter(), [ si.update({word_idf[t.text.lower()]: 1}) for t in nlp(txt) if t.text.lower() in word_idf] )[0]
+wordidf = lambda txt:  (si := Counter(), [ si.update({word_idf[t.text.lower()]: 1}) for t in spacy.nlp(txt) if t.text.lower() in word_idf] )[0]
 @app.get('/yulk/vs/wordidf') 
 def vs_wordidf(text0="I think that I am going to go to the cinema. The quick fox jumped over the lazy dog.", text1="The reality that has blocked my path to become the typical successful student is that engineering and the liberal arts simply don't mix as easily as I assured in hight school.",):  
 	''' 单词难度对比 ''' 
@@ -30,7 +31,7 @@ def wordmap(snts:list=["I think that I am going to go to the cinema.","The quick
 	ssi = defaultdict(Counter)
 	pos = poslist.strip().split(',')
 	for snt in snts:
-		doc = nlp(snt) 
+		doc = spacy.nlp(snt) 
 		[ ssi[t.pos_].update({t.lemma_:1})  for t in doc if t.pos_ in pos]
 	return ssi 
 
@@ -64,12 +65,12 @@ def essaytag_clear():
 def add_text(text:str="The quick fox jumped over the lazy dog. The justice delayed is justice denied.", title:str=None, note:str=""):
 	''' prefix: my/tag '''
 	cursor=db.conn.cursor()
-	docsnts = snts(text,False)
+	docsnts = spacy.snts(text,False)
 	if not title: title = docsnts[0]
 	cursor.execute(f'INSERT INTO doc(title,body,note) VALUES (?,?,?)',(title, text, note))
 	id = cursor.lastrowid
 	for i, snt in enumerate(docsnts):
-		doc = nlp(snt)
+		doc = spacy.nlp(snt)
 		db[snt] = tobs(doc)
 		cursor.execute(f'INSERT or ignore INTO snt(sid, snt) VALUES (?,?)',(f"{id}-{i}",snt))
 		for t in doc: 
@@ -80,6 +81,16 @@ def add_text(text:str="The quick fox jumped over the lazy dog. The justice delay
 	db.conn.commit()
 	return id 
 
-if __name__ == "__main__":  
-	print(add_text(), flush=True)
+
+class util(object): 
+	def __init__(self): pass 
+
+	def uvirun(self, port) : 
+		''' python -m uvirun.yulk uvirun 18001 '''
+		uvicorn.run(app, host='0.0.0.0', port=port)
+
+if __name__ == '__main__':
+	import fire
+	fire.Fire(util)
+	#print(add_text(), flush=True)
 	#uvicorn.run(app, host='0.0.0.0', port=80)
\ No newline at end of file
